function [G1,G2]=dlqdu_pi(A,B,D,Q,Rw);
% DLQDU_PI
% [G1,G2]=dlqdu_pi(A,B,D,Q,R);
% Purpose
% Compute LQ-optimal control feedback matrices G1 and G2 for
% the controller
% u=u+G1*(x-x_old)+G2*(y_old-r);
% On input
% A,B,D - discrete state space model matrices.
% Q - Wheigting matrix for the output vector y_k.
% R - Weighting matrix for the control deviation vector, Delta u_k=u_k-u_(k-1).

%% Make augmented state space model for LQ-design.
nx=size(A,1); nu=size(B,2); ny=size(D,1);
At=[A,zeros(nx,ny);D,eye(ny,ny)];Bt=[B;zeros(ny,nu)];Dt=[D,eye(ny,ny)];
Qt=Dt'*Q*Dt;

%% Solve Riccati-equation and compute feedback matrix.
[K,Rr]=dlqr(At,Bt,Qt,Rw);
G=-K; 
G1=G(:,1:nx); G2=G(:,nx+1:nx+ny);

% for test
%G1s=zeros(nu,nx); G1s(1,end)=G1(1,end); G1s(end,1)=G1(end,1); G1s
%G2s=zeros(nu,ny); G2s(1,end)=G2(1,end); G2s(end,1)=G2(end,1); G2s

%th_0=[G1(1,end);G1(end,1);G2(1,end);G2(end,1)];
%J=fun_lqdu(th_0,At,Bt,Qt,Rw,nx,nu,ny)
%th=fminunc('fun_lqdu',th_0,[],At,Bt,Qt,Rw,nx,nu,ny)
%eig(At+Bt*[G1 G2])