function [f] = fcol(x,u,v);
% [f]=fcol(x,u,v)
% Return the right hand side of the non-linear distillation
% column model.
%
%  dot(x) = f(x,u,v)
%
% where
% u=[R;V]  The control input variables, (reflux and steam flowrate).
% v=[F;xf] The disturbances, (feed massflowrate and feed composition)

y=zeros(8,1);m=zeros(8,1);f=zeros(8,1);
alfa = 2.993;
R = u(1);
V = u(2);
F = v(1);
xf= v(2);
m(1)=10 + (R+F-V)/30; 
for i=2:7
  m(i)=5 + (R+F)/30;
end
m(8)=10 + (V-R)/30;
for i=1:8
  y(i) = alfa*x(i)/(1+(alfa-1)*x(i));
end
%
f(1) = (V*x(1) - (R+F)*x(1) - V*y(1) + (R+F)*x(2))/m(1);
f(2) = (V*y(1) - (R+F)*x(2) - V*y(2) + (R+F)*x(3))/m(2);
f(3) = (V*y(2) - (R+F)*x(3) - V*y(3) + (R+F)*x(4))/m(3);
f(4) = (V*y(3) - (R+F)*x(4) - V*y(4) + (R+0)*x(5) + F*xf)/m(4);
f(5) = (V*y(4) - (R+0)*x(5) - V*y(5) + (R+0)*x(6))/m(5);
f(6) = (V*y(5) - (R+0)*x(6) - V*y(6) + (R+0)*x(7))/m(6);
f(7) = (V*y(6) - (R+0)*x(7) - V*y(7) + (R+0)*x(8))/m(7);
f(8) = (V*y(7) -     V*x(8))/m(8);


