function [a,b,c,d]=fx2abcd(x,u,v);
% [A,B,C,D]=fx2abcd(x,u,v)
% Purpose:
% fx2abcd is used to determine the linearized distillation column
% model matrices A,B,C and D.
% dot(x)  = f(x,u,v)            - nonlinear model
% dot(dx) = A dx + B du + C dv  - linearized model
%     dy  = D dx
% On input:
% x  composition profile (8 x 1) vector.
% u  control input vector, u=[R;V]
% v  disturbance vector, v=[F;xf]
% On output
% A,B,C,D - linearized model matrices

alfa=2.993;
R=u(1); V=u(2); F=v(1); xf=v(2);
%
for i=1:8
  K(i) = alfa/(1+(alfa-1)*x(i))^2;
  y(i) = alfa*x(i)/(1+(alfa-1)*x(i));
end
Kt=30;
m(1) = 10 + (R+F-V)/Kt;
for i=2:7
  m(i) = 5 + (R+F)/Kt;
end
m(8) = 10 + (V-R)/Kt;
%
% The A=df/dx matrix
a=zeros(8,8);
B=R+F-V; Qs = R + F;
a(1,1) = -(B+V*K(1))/m(1);  a(1,2) = Qs/m(1); 
a(2,1) =      V*K(1)/m(2);  a(2,2) = -(Qs+V*K(2))/m(2); a(2,3) = Qs/m(2);    
a(3,2) =      V*K(2)/m(3);  a(3,3) = -(Qs+V*K(3))/m(3); a(3,4) = Qs/m(3);
a(4,3) =      V*K(3)/m(4);  a(4,4) = -(Qs+V*K(4))/m(4); a(4,5) =  R/m(4);
a(5,4) =      V*K(4)/m(5);  a(5,5) = -(R +V*K(5))/m(5); a(5,6) =  R/m(5);
a(6,5) =      V*K(5)/m(6);  a(6,6) = -(R +V*K(6))/m(6); a(6,7) =  R/m(6);
a(7,6) =      V*K(6)/m(7);  a(7,7) = -(R +V*K(7))/m(7); a(7,8) =  R/m(7);
a(8,7) =      V*K(7)/m(8);  a(8,8) = -V/m(8);
%
b=zeros(8,2);
b(1,1) = (x(2)-x(1))/m(1); b(1,2) = (x(1)-y(1))/m(1);
b(2,1) = (x(3)-x(2))/m(2); b(2,2) = (y(1)-y(2))/m(2);
b(3,1) = (x(4)-x(3))/m(3); b(3,2) = (y(2)-y(3))/m(3);
b(4,1) = (x(5)-x(4))/m(4); b(4,2) = (y(3)-y(4))/m(4);
b(5,1) = (x(6)-x(5))/m(5); b(5,2) = (y(4)-y(5))/m(5);
b(6,1) = (x(7)-x(6))/m(6); b(6,2) = (y(5)-y(6))/m(6);
b(7,1) = (x(8)-x(7))/m(7); b(7,2) = (y(6)-y(7))/m(7);
b(8,1) = 0;                b(8,2) = (y(7)-x(8))/m(8);
%
d=zeros(2,8);
d(1,1)=1; d(2,8)=1;
%
c=zeros(8,2);
c(1,1) = (x(2)-x(1))/m(1); 
c(2,1) = (x(3)-x(2))/m(2); 
c(3,1) = (x(4)-x(3))/m(3); 
c(4,1) = (x(5)-x(4))/m(4); c(4,2) = F/m(4); 


