% main_kolreg_lq
% Simuleringsprogram for diskret LQ optimal PI regulering av en destillasjonskolonne.
% DDIR november 2001
% Avhengige funksjoner: dlqdu_pi.m
clear
%path(path,'s:\tex3\home\dlqdu_paper\matlab')

ireg=2;
ireg=dread('LQ-optimal PI (2) eller PI (1)',ireg);

u=[2;2.5];                                       % Stasjonaerverdier, u_1=R og u_2=V.
v=[1;0.5];                                       % v_1=F og v_2=x_F
r=[0.04;0.96];                                   % Referanser for bunn og topp-produkt.

h=5.0;                                           % Samplingstid
t=0:h:250;                                       % Simuleringshorisont.
N=length(t);
X=zeros(N,8); Y=zeros(N,2); U=zeros(N,2); T=zeros(N,1);

x0=(0.2:0.1:0.9)'
x0=ssprof2(u,v,2);                               % Stasjonrt konsentrasjonsprofil.

D=zeros(2,8); D(1,1)=1; D(2,8)=1;

if ireg==2                                       % LQ-optimal PI regulator
  q=2500; q=dread('q=',q);
  [Ac,Bc,Cc,Dc]=fx2abcd(x0,u,v);                 % Matriser i kontinuerlig modell.
  [A,B,D,E]=c2dm(Ac,Bc,Dc,zeros(2,2),h,'zoh')    % Diskret modell.
  P=eye(2); Q=eye(2)*q;                          % Vektmatriser
  [G1,G2]=dlqdu_pi(A,B,D,Q,P);
  
  %nx=size(A,1); nu=size(B,2); ny=size(D,1);
  %G1s=zeros(nu,nx); G1s(1,end)=G1(1,end); G1s(end,1)=G1(end,1); G1=G1s;
  %G2s=zeros(nu,ny); G2s(1,end)=G2(1,end); G2s(end,1)=G2(end,1); G2=G2s;
 
elseif ireg==1                                  % Konvensjonell PI regulator
  Kp1=-20.3; Ti1=6.12; 
  Kp2=239*0.2; Ti2=22*0.5;
  G1=[0,Kp1;Kp2,0]; G2=[0,Kp1/Ti1;Kp2/Ti2,0];
  z=-inv(G2)*u;
end


Tall=[]; Xall=[]; Uall=[]; Rall=[];
x=x0; x_old=x; y_old=D*x;                     % Initialiseringer
for k=1:N-1
   y=D*x;                                     % Mling
   
   if t(k)>50; r(2)=0.97; end                 % Referanseendringer
   if t(k)>150; r(1)=0.05; end
   
   if ireg==1                                 % Konvensjonell PI-regulator
     % Diskret PI regulator
     %u=-G1*(r-D*x)+G2*z
     %z=z+h*(y-r);
   
     u=-G1*(r-y)-G2*z
     z=z+h*(r-y);
   
   elseif ireg==2                             % LQ-optimal PI-regulator.
     u=u+G1*(x-x_old)+G2*(y_old-r);
     y_old=y; x_old=x;
   end
   
   % Integrerer prosessen over samplingsintervallet, dvs. fra t(k) til t(k)+h.
   X(k,:)=x'; Y(k,:)=y'; T(k,1)=t(k); U(k,:)=u';
   [Tk,Xk]=ode15s('fcol2',t(k):0.1:t(k+1),x,[],u,v);
   x=Xk(end,:)';
   Tall=[Tall;Tk]; Xall=[Xall;Xk];            % Lagring...
   nu=length(0:0.1:h);
   Uall=[Uall;[u(1)*ones(nu,1) u(2)*ones(nu,1)]];
   Rall=[Rall;[r(1)*ones(nu,1) r(2)*ones(nu,1)]];
end 
y=D*x; 
X(N,:)=x'; Y(N,:)=y'; T(N,1)=t(N); U(N,:)=u';

%%%%%%%%%%%%%% Plotter resultatene %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure(1)
subplot(211), plot(Tall,[Xall(:,1) Rall(:,1)]), ylabel('x_1=x_B'), grid
title('Top and bottom compositions')
subplot(212), plot(Tall,[Xall(:,8) Rall(:,2)]), ylabel('x_2=x_D'), grid

figure(2)
subplot(211), plot(Tall,Uall(:,1)), ylabel('u_1=R'), grid
title('Column control inputs')
subplot(212), plot(Tall,Uall(:,2)), ylabel('u_2=V'), grid
