function [x,u,v]=ssprof2(u,v,flag);
% [x,u,v]=ssprof(u,v,flag);
% Purpose:
% This function is used to compute the steady state composition
% profile (x=[x1;x2;...x8]) for a specified control input vector  
% (u=[R;V]) and a vector of disturbances (v=[F;xf]) ), i.e. solve
%
%   dot(x) = f(x,u,v) = 0
%
% with respect to x.
% On input:
% u=[R;V]   The control inputs, Reflux and steam flowrate. Default u=[2.0;2.5]
% v=[F;xf]  The disturbances, feed flowrate and feed composition. Default v=[1.0;0.5] 
% flag.     flag = 1 is default. Possibility of changig u and v inside this function 
%           when flag=1.
% On output:
% x         The steady state composition profile, satisfying f(x,u,v)=0.
% u=[R;V]   Changed if new values are specified inside this function.
% v=[F;xf]  Changed if new values are specified inside this function.
%
% Functions called: fsolve, fxval, fchan

% Written 23/3-95 by David Di Ruscio
if nargin == 2; flag=1; end
if nargin == 1; flag=1; u=[2.0;2.5]; end
if nargin == 0; flag=1; u=[2.0;2.5]; v=[1.0;0.5]; end
%
R=u(1);V=u(2);F=v(1);xf=v(2);
if flag == 1
R =fchan('Enter steady state reflux           (u1=R) :',R);
V =fchan('Enter steady state steam flowrate   (u2=V) :',V);
F =fchan('Enter steady state feed flowrate    (v1=F) :',F);
xf=fchan('Enter steady state feed composition (v2=xf):',xf);
end

% Implementering av Newton-Rapsons metode for aa loese f(x)=0
% Dette kan benyttes istedet for fsolv.m i optimization toolbox.
% DDIR, 12/11-1998

us=[R;V]; vs=[F;xf];

x0=((0.1:8)/10)';          % gjetter paa startverdi

iter=10;                   % Eksperimenter litt med antall iterasjoner !!
iter=fchan('Antall iterasjoner ?',iter); 

x=x0;
for it=1:iter
 f=fcol(x,us,vs);          % beregner f(x)
 A=fx2abcd(x,us,vs);       % beregner df/dx=A, dvs. Jacobi matrisen.
 x=x-inv(A)*f;             % x_k+1=x_k - inv(df/dx)*f(x)
end

% Merk: man kan godt benytte en WHILE loekke og teste paa norm(f) > tool
% der tool er en spesifisert toleranse, feks. tool=sqrt(eps).
% Iterasjonsforslaget over er imidlertid meget laererikt.